@@ -299,7 +299,7 @@ if($_SESSION['goip_permissions'] > 1){
 			if($_REQUEST[id])
 				$db->query("update message set receiverid='$Ida', receiverid1='$Idb', receiverid2='$Idc', msg='$_REQUEST[Memo]', userid=$_SESSION[goip_userid],total='$total',crontime=$crontime where id=$_REQUEST[id]");
 			else 
-				$db->query("INSERT INTO message (receiverid,receiverid1,receiverid2,msg,userid,crontime,groupid) VALUES ('$Ida','$Idb','$Idc','$_REQUEST[Memo]',total='$total',$_SESSION[goip_userid],$crontime,'$_REQUEST[groupid]')");	
+				$db->query("INSERT INTO message (receiverid,receiverid1,receiverid2,msg,total,userid,crontime,groupid) VALUES ('$Ida','$Idb','$Idc','$_REQUEST[Memo]','$total',$_SESSION[goip_userid],$crontime,'$_REQUEST[groupid]')");	
 			do_cron($db,$crontime,$goipcronport);
 			exit;
 		}
@@ -353,7 +353,7 @@ if($_SESSION['goip_permissions'] > 1){
 			if($_GET[id])
 				$db->query("update message set type=1,groupid='$Ida', groupid1='$Idb', groupid2='$Idc', msg='$_POST[Memo]', userid=$_SESSION[goip_userid],total='$total',crontime=$crontime where id=$_GET[id]");
 			else 
-				$db->query("INSERT INTO message (type,groupid,groupid1,groupid2,msg,userid,crontime) VALUES (1,'$Ida','$Idb','$Idc','$_POST[Memo]',total='$total',$_SESSION[goip_userid],$crontime)");	
+				$db->query("INSERT INTO message (type,groupid,groupid1,groupid2,msg,total,userid,crontime) VALUES (1,'$Ida','$Idb','$Idc','$_POST[Memo]','$total',$_SESSION[goip_userid],$crontime)");	
 			do_cron($db,$crontime,$goipcronport);
 			exit;
 		}
@@ -401,7 +401,7 @@ elseif(isset($_POST['alltype'])) {//向全部人發送
 		if($_GET[id])
 			$db->query("update message set type=2, recv=$jr, recv1=$jr1, recv2=$jr1, msg='$_POST[Memo]', userid=$_SESSION[goip_userid],total='$total',crontime=$crontime where id=$_GET[id]");
 		else 
-			$db->query("INSERT INTO message (type,msg,userid,crontime,recv,recv1,recv2,total) VALUES (2, '$_POST[Memo]', $_SESSION[goip_userid],'$total',$crontime,$jr,$jr1,$jr2)");	
+			$db->query("INSERT INTO message (type,msg,userid,crontime,recv,recv1,recv2,total) VALUES (2, '$_POST[Memo]', $_SESSION[goip_userid],$crontime,$jr,$jr1,$jr2,'$total')");	
 		do_cron($db,$crontime,$goipcronport);
 		exit;
 	}
