@@ -246,8 +246,9 @@ $select
 EOT;
 $j=0;
 foreach($rsdb as $rs) {
-$rs['msg']=htmlspecialchars($rs['msg']);
-$rs['msg']=str_replace("\n", "<br>", $rs['msg']);
+$rs['USSD_RETURN']=htmlspecialchars($rs['USSD_RETURN']);
+$rs['USSD_RETURN']=str_replace("\n", "<br>", $rs['USSD_RETURN']);
+$rs['USSD_RETURN']=str_replace(" ", "&nbsp;", $rs['USSD_RETURN']);
 print <<<EOT
 -->
         <tr class="even" onMouseOver="mouseover(this)" onMouseOut="mouseout(this)" onMouseDown="trclick(this)">
